pub struct SugiyamaLayout {
pub coords: Matrix,
pub routing: Vec<Matrix>,
}Expand description
Result of Graph::layout_sugiyama.
Fields
coords: MatrixThe vertex coordinates, n × 2; the y coordinate of a vertex is
its layer index times vgap.
routing: Vec<Matrix>One matrix per edge with the extra control points (one per row) the edge must pass through, from its source to its target; edges spanning adjacent layers have a 0 × 2 matrix.