pub struct SugiyamaOptions<'a> {
pub layers: Option<&'a [i64]>,
pub hgap: f64,
pub vgap: f64,
pub maxiter: usize,
pub weights: Option<&'a [f64]>,
}Expand description
Parameters of the Sugiyama layered layout (Graph::layout_sugiyama).
The Default uses automatic layering, unit gaps, 100 crossing
minimization iterations and unit weights.
Fields
layers: Option<&'a [i64]>Non-negative layer index of every vertex. Empty layers are skipped
when minimizing crossings, but keep their room on the y axis.
None lets igraph compute a layering, after breaking cycles.
hgap: f64Preferred minimum horizontal gap between vertices of a layer (default 1).
vgap: f64Distance between consecutive layers (default 1).
maxiter: usizeMaximum number of iterations of the crossing minimization (default 100).
weights: Option<&'a [f64]>Edge weights, used only to break cycles: igraph tends to reverse edges with smaller weights.
Implementations
Sourceimpl<'a> SugiyamaOptions<'a>
impl<'a> SugiyamaOptions<'a>
Sourcepub fn with_layers(self, layers: &'a [i64]) -> Self
pub fn with_layers(self, layers: &'a [i64]) -> Self
Sets the layer of each vertex.